//
//  ViewController.swift
//  Gmail
//
//  Created by Matthew Newill on 01/02/2019.
//  Copyright © 2019 DevFright. All rights reserved.
//

import UIKit
import GoogleAPIClientForREST
import GoogleSignIn
import GTMSessionFetcher


class ViewController: UIViewController, GIDSignInUIDelegate {
    
    @IBOutlet weak var name: UILabel!
    @IBOutlet weak var emailAddress: UILabel!

    override func viewDidLoad() {
        super.viewDidLoad()
        // Do any additional setup after loading the view, typically from a nib.
        
        GIDSignIn.sharedInstance().uiDelegate = self
    }
    
    @IBAction func didTapSignOut(_ sender: AnyObject) {
        GIDSignIn.sharedInstance().signOut()
        name.text = "Signed Out"
        emailAddress.text = ""
    }
    
    @IBAction func fetchLatestMessageID(_ sender: Any) {
        listInboxMessages()
    }
    
    func listInboxMessages() {
        let gmailService = GTLRGmailService.init()
        
        let listQuery = GTLRGmailQuery_UsersMessagesList.query(withUserId: "me")
        listQuery.labelIds = ["INBOX"]
        
        let authorizer = GIDSignIn.sharedInstance()?.currentUser?.authentication?.fetcherAuthorizer()
        gmailService.authorizer = authorizer
        
        gmailService.executeQuery(listQuery) { (ticket, response, error) in
            if response != nil {
                print("Response: ")
                print(response)
                self.getFirstMessageIdFromMessages(response: response as! GTLRGmail_ListMessagesResponse)
            } else {
                print("Error: ")
                print(error)
            }
        }
    }
    
    func getFirstMessageIdFromMessages(response: GTLRGmail_ListMessagesResponse) {
        let messagesResponse = response as GTLRGmail_ListMessagesResponse
        print("Latest Message: ")
        print(messagesResponse.messages![0].identifier)
    }

    // MARK: - GIDSignInUIDelegate Delegates
    func sign(inWillDispatch signIn: GIDSignIn!, error: Error!) {
        //myActivityIndicator.stopAnimating()
        name.text = GIDSignIn.sharedInstance()?.currentUser?.profile?.name
        emailAddress.text = GIDSignIn.sharedInstance()?.currentUser?.profile?.email
    }
    
    func sign(_ signIn: GIDSignIn!, present viewController: UIViewController!) {
        self.present(viewController, animated: true, completion: nil)
    }
    
    func sign(_ signIn: GIDSignIn!, dismiss viewController: UIViewController!) {
        self.dismiss(animated: true, completion: nil)
    }
    
}
